## TODOs

No particular order, and not inclusive:

* Tools & scripts for helping with PyLadies chapter admin management
* Website contributing & local chapter website creation how-to
* Global Newsletter how-to
* Info on trademark
* Company and Community relationships
* History and background
* PyLadies' cultivated resources

Submit ideas by filing issues and/or pull requests!